PlayerRole

Enum PlayerRole 

#[repr(u8)]
pub enum PlayerRole { Default = 0, Admin = 1, SuperAdmin = 2, }
Enum for the different roles that a player could have used to determine their permissions to access different server functionality

Variants



Default = 0

The default no extra permissions level



Admin = 1

Administrator role which can be added and removed by super admin.



SuperAdmin = 2

Super admin role which is created on startup and used to manage other user roles